@@ -481,7 +481,7 @@ void KateFileTreeModel::setShowFullPathOnRoots(bool s)
         m_root->clearFlag(ProxyItem::ShowFullPath);
     }
 
-    const auto rootChildren = m_root->children();
+    const std::vector<ProxyItem *> &rootChildren = m_root->children();
     for (ProxyItem *root : rootChildren) {
         root->updateDisplay();
     }
@@ -533,7 +533,7 @@ void KateFileTreeModel::clearModel()
     endResetModel();
 }
 
-void KateFileTreeModel::connectDocument(const KTextEditor::Document *doc)
+void KateFileTreeModel::connectDocument(const KTextEditor::Document *doc) const
 {
     connect(doc, &KTextEditor::Document::documentNameChanged, this, &KateFileTreeModel::documentNameChanged);
     connect(doc, &KTextEditor::Document::documentUrlChanged, this, &KateFileTreeModel::documentNameChanged);
@@ -549,15 +549,15 @@ QModelIndex KateFileTreeModel::docIndex(const KTextEditor::Document *doc) const
     if (it == m_docmap.end()) {
         return {};
     }
-    auto item = it.value();
+    ProxyItem *item = it.value();
     return createIndex(item->row(), 0, item);
 }
 
 QModelIndex KateFileTreeModel::widgetIndex(QWidget *widget) const
 {
     ProxyItem *item = nullptr;
-    const auto items = m_widgetsRoot->children();
-    for (auto *it : items) {
+    const std::vector<ProxyItem *> &items = m_widgetsRoot->children();
+    for (ProxyItem *it : items) {
         if (it->widget() == widget) {
             item = it;
             break;
@@ -602,7 +602,7 @@ QVariant KateFileTreeModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    ProxyItem *item = static_cast<ProxyItem *>(index.internalPointer());
+    auto *item = static_cast<ProxyItem *>(index.internalPointer());
     if (!item) {
         return QVariant();
     }
@@ -680,14 +680,14 @@ QMimeData *KateFileTreeModel::mimeData(const QModelIndexList &indexes) const
         return nullptr;
     }
 
-    ProxyItem *item = static_cast<ProxyItem *>(indexes.at(0).internalPointer());
+    auto *item = static_cast<ProxyItem *>(indexes.at(0).internalPointer());
     QList<QUrl> urls;
     if (!item || !item->doc() || !item->doc()->url().isValid()) {
         return nullptr;
     }
     urls.append(item->doc()->url());
 
-    FileTreeMimeData *mimeData = new FileTreeMimeData(indexes.at(0));
+    auto *mimeData = new FileTreeMimeData(indexes.at(0));
     mimeData->setUrls(urls);
     return mimeData;
 }
@@ -714,7 +714,7 @@ bool KateFileTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction, int
     }
 
     auto parentItem = parent.isValid() ? static_cast<ProxyItemDir *>(parent.internalPointer()) : m_root;
-    auto &childs = parentItem->children();
+    std::vector<ProxyItem *> &childs = parentItem->children();
     int sourceRow = index.row();
 
     beginMoveRows(index.parent(), index.row(), index.row(), parent, row);
@@ -840,7 +840,7 @@ ProxyItem *KateFileTreeModel::itemForIndex(const QModelIndex &index) const
         return m_root;
     }
 
-    ProxyItem *item = static_cast<ProxyItem *>(index.internalPointer());
+    auto *item = static_cast<ProxyItem *>(index.internalPointer());
     if (!item) {
         return nullptr;
     }
@@ -849,7 +849,7 @@ ProxyItem *KateFileTreeModel::itemForIndex(const QModelIndex &index) const
 
 bool KateFileTreeModel::isDir(const QModelIndex &index) const
 {
-    if (auto item = itemForIndex(index)) {
+    if (ProxyItem *item = itemForIndex(index)) {
         return item->flag(ProxyItem::Dir) && !item->flag(ProxyItem::Widget);
     }
     return false;
@@ -857,7 +857,7 @@ bool KateFileTreeModel::isDir(const QModelIndex &index) const
 
 bool KateFileTreeModel::isWidgetDir(const QModelIndex &index) const
 {
-    if (auto item = itemForIndex(index)) {
+    if (ProxyItem *item = itemForIndex(index)) {
         return item->flag(ProxyItem::Dir) && item->flag(ProxyItem::Widget);
     }
     return false;
@@ -880,7 +880,7 @@ void KateFileTreeModel::setListMode(bool lm)
 
 void KateFileTreeModel::documentOpened(KTextEditor::Document *doc)
 {
-    ProxyItem *item = new ProxyItem(QString());
+    auto *item = new ProxyItem(QString());
     item->setDoc(doc);
 
     updateItemPathAndHost(item);
@@ -1147,7 +1147,7 @@ void KateFileTreeModel::documentNameChanged(KTextEditor::Document *doc)
 
 ProxyItemDir *KateFileTreeModel::findRootNode(const QString &name, const int r) const
 {
-    const auto rootChildren = m_root->children();
+    const std::vector<ProxyItem *> &rootChildren = m_root->children();
     for (ProxyItem *item : rootChildren) {
         if (!item->flag(ProxyItem::Dir)) {
             continue;
@@ -1177,8 +1177,7 @@ ProxyItemDir *KateFileTreeModel::findChildNode(const ProxyItemDir *parent, const
         return nullptr;
     }
 
-    const auto children = parent->children();
-    for (ProxyItem *item : children) {
+    for (ProxyItem *item : parent->children()) {
         if (!item->flag(ProxyItem::Dir)) {
             continue;
         }
@@ -1263,7 +1262,7 @@ void KateFileTreeModel::handleInsert(ProxyItem *item)
     QString base = item->path().section(QLatin1Char('/'), 0, -2);
 
     // create new root
-    ProxyItemDir *new_root = new ProxyItemDir(base);
+    auto *new_root = new ProxyItemDir(base);
     new_root->setHost(item->host());
 
     // add new root to m_root
@@ -1275,7 +1274,7 @@ void KateFileTreeModel::handleInsert(ProxyItem *item)
     base += QLatin1Char('/');
 
     // try and merge existing roots with the new root node (new_root.path < root.path)
-    const auto rootChildren = m_root->children();
+    const std::vector<ProxyItem *> &rootChildren = m_root->children();
     for (ProxyItem *root : rootChildren) {
         if (root == new_root || !root->flag(ProxyItem::Dir)) {
             continue;
@@ -1321,7 +1320,8 @@ void KateFileTreeModel::handleDuplicitRootDisplay(ProxyItemDir *init)
             continue;
         }
 
-        const auto rootChildren = m_root->children();
+        // iterate on copy
+        const std::vector<ProxyItem *> rootChildren = m_root->children();
         for (ProxyItem *root : rootChildren) {
             if (root == check_root || !root->flag(ProxyItem::Dir)) {
                 continue;
@@ -1337,14 +1337,15 @@ void KateFileTreeModel::handleDuplicitRootDisplay(ProxyItemDir *init)
                     m_root->removeChild(root);
                     endRemoveRows();
 
-                    ProxyItemDir *irdir = new ProxyItemDir(rdir);
+                    auto *irdir = new ProxyItemDir(rdir);
                     beginInsertRows(QModelIndex(), m_root->childCount(), m_root->childCount());
                     m_root->addChild(irdir);
                     endInsertRows();
 
                     insertItemInto(irdir, root);
 
-                    const auto children = m_root->children();
+                    // iterate on copy
+                    const std::vector<ProxyItem *> children = m_root->children();
                     for (ProxyItem *node : children) {
                         if (node == irdir || !root->flag(ProxyItem::Dir)) {
                             continue;
@@ -1372,7 +1373,7 @@ void KateFileTreeModel::handleDuplicitRootDisplay(ProxyItemDir *init)
                         m_root->removeChild(check_root);
                         endRemoveRows();
 
-                        ProxyItemDir *irdir = new ProxyItemDir(nrdir);
+                        auto *irdir = new ProxyItemDir(nrdir);
                         beginInsertRows(QModelIndex(), m_root->childCount(), m_root->childCount());
                         m_root->addChild(irdir);
                         endInsertRows();
@@ -1486,7 +1487,7 @@ void KateFileTreeModel::addWidget(QWidget *w)
 
     const QModelIndex parentIdx = createIndex(m_widgetsRoot->row(), 0, m_widgetsRoot);
     beginInsertRows(parentIdx, m_widgetsRoot->childCount(), m_widgetsRoot->childCount());
-    auto item = new ProxyItem(w->windowTitle());
+    auto *item = new ProxyItem(w->windowTitle());
     item->setFlag(ProxyItem::Widget);
     item->setIcon(w->windowIcon());
     item->setWidget(w);
@@ -1497,8 +1498,8 @@ void KateFileTreeModel::addWidget(QWidget *w)
 void KateFileTreeModel::removeWidget(QWidget *w)
 {
     ProxyItem *item = nullptr;
-    const auto items = m_widgetsRoot->children();
-    for (auto *it : items) {
+    const std::vector<ProxyItem *> &items = m_widgetsRoot->children();
+    for (ProxyItem *it : items) {
         if (it->widget() == w) {
             item = it;
             break;
