@@ -183,7 +183,7 @@ KateGitBlamePluginView::KateGitBlamePluginView(KateGitBlamePlugin *plugin, KText
     setXMLFile(QStringLiteral("ui.rc"));
     QAction *showBlameAction = actionCollection()->addAction(QStringLiteral("git_blame_show"));
     showBlameAction->setText(i18n("Show Git Blame Details"));
-    actionCollection()->setDefaultShortcut(showBlameAction, QKeySequence(QStringLiteral("Ctrl+T, B"), QKeySequence::PortableText));
+    KActionCollection::setDefaultShortcut(showBlameAction, QKeySequence(QStringLiteral("Ctrl+T, B"), QKeySequence::PortableText));
     QAction *toggleBlameAction = actionCollection()->addAction(QStringLiteral("git_blame_toggle"));
     toggleBlameAction->setText(i18n("Toggle Git Blame Details"));
     m_mainWindow->guiFactory()->addClient(this);
@@ -212,9 +212,11 @@ KateGitBlamePluginView::KateGitBlamePluginView(KateGitBlamePlugin *plugin, KText
         m_tooltip.hide();
     });
 
-    connect(&m_blameInfoProc, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &KateGitBlamePluginView::blameFinished);
+    connect(&m_blameInfoProc, &QProcess::finished, this, &KateGitBlamePluginView::commandFinished);
+    connect(&m_showProc, &QProcess::finished, this, &KateGitBlamePluginView::showFinished);
 
-    connect(&m_showProc, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &KateGitBlamePluginView::showFinished);
+    connect(&m_blameInfoProc, &QProcess::errorOccurred, this, &KateGitBlamePluginView::onErrorOccurred);
+    connect(&m_showProc, &QProcess::errorOccurred, this, &KateGitBlamePluginView::onErrorOccurred);
 
     m_inlineNoteProvider.setMode(KateGitBlameMode::SingleLine);
 }
@@ -269,13 +271,15 @@ void KateGitBlamePluginView::startGitBlameForActiveView()
 
 void KateGitBlamePluginView::startBlameProcess(const QUrl &url)
 {
+    const QFileInfo fi{url.toLocalFile()};
     // same document? maybe split view? => no work to do, reuse the result we already have
-    if (m_blameUrl == url) {
+    if (fi.absoluteFilePath() == m_absoluteFilePath) {
         return;
     }
+    m_parentPath = fi.absolutePath();
+    m_absoluteFilePath = fi.absoluteFilePath();
 
     // clear everything
-    m_blameUrl.clear();
     m_blamedLines.clear();
     m_blameInfoForHash.clear();
 
@@ -285,12 +289,11 @@ void KateGitBlamePluginView::startBlameProcess(const QUrl &url)
         m_blameInfoProc.waitForFinished();
     }
 
-    const QFileInfo fi{url.toLocalFile()};
-    if (!setupGitProcess(m_blameInfoProc, fi.absolutePath(), {QStringLiteral("blame"), QStringLiteral("-p"), fi.absoluteFilePath()})) {
+    m_currentCommand = Command::RevParse;
+    if (!setupGitProcess(m_blameInfoProc, m_parentPath, {QStringLiteral("rev-parse"), QStringLiteral("--show-toplevel")})) {
         return;
     }
     startHostProcess(m_blameInfoProc, QIODevice::ReadOnly);
-    m_blameUrl = url;
 }
 
 void KateGitBlamePluginView::startShowProcess(const QUrl &url, const QString &hash)
@@ -301,6 +304,7 @@ void KateGitBlamePluginView::startShowProcess(const QUrl &url, const QString &ha
     }
 
     const QFileInfo fi{url.toLocalFile()};
+    m_absoluteFilePath = fi.absoluteFilePath();
     if (!setupGitProcess(m_showProc, fi.absolutePath(), {QStringLiteral("show"), hash, QStringLiteral("--numstat")})) {
         return;
     }
@@ -333,14 +337,58 @@ void KateGitBlamePluginView::sendMessage(const QString &text, bool error)
     Utils::showMessage(text, gitIcon(), i18n("Git"), error ? MessageType::Error : MessageType::Info, m_mainWindow);
 }
 
-void KateGitBlamePluginView::blameFinished(int exitCode, QProcess::ExitStatus exitStatus)
+void KateGitBlamePluginView::commandFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
     // we ignore errors, we might just not be in a git repo, parsing errors is hard, as they are translated
     // switching to english is no good idea either, as the user will likely not understand it then anyways
-    if (exitCode != 0 || exitStatus != QProcess::NormalExit) {
+    // Git returns error code 1 if IgnoreRevsFile is not found, so we ignore the error for it
+    if (m_currentCommand != Command::IgnoreRevsFile && (exitCode != 0 || exitStatus != QProcess::NormalExit)) {
         return;
     }
 
+    switch (m_currentCommand) {
+    case Command::RevParse: {
+        m_root = QString::fromUtf8(m_blameInfoProc.readAllStandardOutput().trimmed());
+
+        if (!setupGitProcess(m_blameInfoProc, m_parentPath, {QStringLiteral("config"), QStringLiteral("blame.ignoreRevsFile")})) {
+            return;
+        }
+        m_currentCommand = Command::IgnoreRevsFile;
+        startHostProcess(m_blameInfoProc, QIODevice::ReadOnly);
+        break;
+    }
+    case Command::Config: {
+        m_ignoreRevsFile = QString::fromUtf8(m_blameInfoProc.readAllStandardOutput().trimmed());
+
+        auto arguments = QStringList{QStringLiteral("blame"), QStringLiteral("-p")};
+
+        // add ignore-revs-file
+        const auto ignoreRevFile = !m_ignoreRevsFile.isEmpty() ? m_ignoreRevsFile : QStringLiteral(".git-blame-ignore-revs");
+        const auto ignoreRevFilePath = QStringLiteral("%1/%2").arg(m_root, ignoreRevFile);
+        if (QFileInfo::exists(ignoreRevFilePath)) {
+            arguments.append({QStringLiteral("--ignore-revs-file"), ignoreRevFilePath});
+        }
+        arguments.append(m_absoluteFilePath);
+
+        m_currentCommand = Command::Blame;
+        if (!setupGitProcess(m_blameInfoProc, m_parentPath, arguments)) {
+            return;
+        }
+        startHostProcess(m_blameInfoProc, QIODevice::ReadOnly);
+        break;
+    }
+    case Command::Blame:
+        parseGitBlameStdOutput();
+        break;
+    case Command::IgnoreRevsFile:
+        m_currentCommand = Command::Config;
+        commandFinished(0, QProcess::ExitStatus::NormalExit);
+        break;
+    }
+}
+
+void KateGitBlamePluginView::parseGitBlameStdOutput()
+{
     QByteArray out = m_blameInfoProc.readAllStandardOutput();
     out.replace("\r", ""); // KTextEditor removes all \r characters in the internal buffers
     // printf("recieved output: %d for: git %s\n", out.size(), qPrintable(m_blameInfoProc.arguments().join(QLatin1Char(' '))));
@@ -564,7 +612,7 @@ const CommitInfo &KateGitBlamePluginView::blameGetUpdateInfo(int lineNr)
     return m_blameInfoForHash[commitInfo.shortCommitHash];
 }
 
-void KateGitBlamePluginView::setToolTipIgnoreKeySequence(QKeySequence sequence)
+void KateGitBlamePluginView::setToolTipIgnoreKeySequence(const QKeySequence &sequence)
 {
     m_tooltip.setIgnoreKeySequence(sequence);
 }
@@ -576,4 +624,13 @@ void KateGitBlamePluginView::showCommitTreeView(const QUrl &url)
     CommitView::openCommit(commitHash, file, m_mainWindow);
 }
 
+void KateGitBlamePluginView::onErrorOccurred(QProcess::ProcessError e)
+{
+    auto process = qobject_cast<QProcess *>(sender());
+    if (process) {
+        qWarning() << process->program() << process->arguments() << "Failed to start with error: " << e;
+        sendMessage(QStringLiteral("%1 with args %2, error occurred: %3.").arg(process->program(), process->arguments().join(QLatin1Char(' '))).arg(e), false);
+    }
+}
+
 #include "kategitblameplugin.moc"
