@@ -76,7 +76,7 @@ KateCTagsView::KateCTagsView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
     updateDB->setText(i18n("Configure ..."));
     connect(updateDB, &QAction::triggered, this, [this, plugin](bool) {
         if (m_mWin) {
-            KateCTagsPlugin *p = static_cast<KateCTagsPlugin *>(plugin);
+            auto *p = static_cast<KateCTagsPlugin *>(plugin);
             QDialog *confWin = new QDialog(m_mWin->window());
             confWin->setAttribute(Qt::WA_DeleteOnClose);
             auto confPage = p->configPage(0, confWin);
@@ -140,12 +140,12 @@ KateCTagsView::KateCTagsView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
     m_gotoSymbWidget.reset(new GotoSymbolWidget(mainWin, this));
     auto openLocal = actionCollection()->addAction(QStringLiteral("open_local_gts"));
     openLocal->setText(i18n("Go To Local Symbol"));
-    actionCollection()->setDefaultShortcut(openLocal, Qt::CTRL | Qt::ALT | Qt::Key_P);
+    KActionCollection::setDefaultShortcut(openLocal, Qt::CTRL | Qt::ALT | Qt::Key_P);
     connect(openLocal, &QAction::triggered, this, &KateCTagsView::showSymbols);
 
     auto openGlobal = actionCollection()->addAction(QStringLiteral("open_global_gts"));
     openGlobal->setText(i18n("Go To Global Symbol"));
-    actionCollection()->setDefaultShortcut(openGlobal, Qt::CTRL | Qt::SHIFT | Qt::Key_P);
+    KActionCollection::setDefaultShortcut(openGlobal, Qt::CTRL | Qt::SHIFT | Qt::Key_P);
     connect(openGlobal, &QAction::triggered, this, &KateCTagsView::showGlobalSymbols);
 
     connect(m_ctagsUi.inputEdit, &QLineEdit::textChanged, this, &KateCTagsView::startEditTmr);
@@ -328,10 +328,10 @@ void KateCTagsView::gotoResults(const QString &word, const Tags::TagList &list)
     displayHits(list);
 
     if (list.count() == 1) {
-        Tags::TagEntry tag = list.first();
+        const Tags::TagEntry &tag = list.first();
         jumpToTag(tag.file, tag.pattern, word);
     } else {
-        Tags::TagEntry tag = list.first();
+        const Tags::TagEntry &tag = list.first();
         jumpToTag(tag.file, tag.pattern, word);
         m_ctagsUi.tabWidget->setCurrentIndex(0);
         m_mWin->showToolView(m_toolView);
@@ -626,7 +626,7 @@ bool KateCTagsView::listContains(const QString &target)
 bool KateCTagsView::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress) {
-        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
+        auto *ke = static_cast<QKeyEvent *>(event);
         if ((obj == m_toolView) && (ke->key() == Qt::Key_Escape)) {
             m_mWin->hideToolView(m_toolView);
             event->accept();
@@ -649,7 +649,7 @@ void KateCTagsView::handleEsc(QEvent *e)
         return;
     }
 
-    QKeyEvent *k = static_cast<QKeyEvent *>(e);
+    auto *k = static_cast<QKeyEvent *>(e);
     if (k->key() == Qt::Key_Escape && k->modifiers() == Qt::NoModifier) {
         if (m_toolView->isVisible()) {
             m_mWin->hideToolView(m_toolView);
