@@ -1,5 +1,4 @@
-#ifndef KATE_CTAGS_VIEW_H
-#define KATE_CTAGS_VIEW_H
+#pragma once
 /* Description : Kate CTags plugin
  *
  * SPDX-FileCopyrightText: 2008-2011 Kare Sars <kare.sars@iki.fi>
@@ -96,7 +95,7 @@ private:
     void setNewLookupText(const QString &newText);
     void displayHits(const Tags::TagList &list);
 
-    void gotoTagForTypes(const QString &tag, QStringList const &types);
+    void gotoResults(const QString &word, const Tags::TagList &list);
 
     QPointer<KTextEditor::MainWindow> m_mWin;
     QPointer<QWidget> m_toolView;
@@ -114,5 +113,3 @@ private:
     QTimer m_editTimer;
     QStack<TagJump> m_jumpStack;
 };
-
-#endif
