@@ -24,7 +24,6 @@
 #include <QProcess>
 #include <QScrollBar>
 #include <QStyledItemDelegate>
-#include <QtConcurrent>
 
 #include <KColorScheme>
 #include <KLocalizedString>
@@ -97,7 +96,7 @@ KateProjectViewTree::KateProjectViewTree(KateProjectPluginView *pluginView, Kate
      */
     QItemSelectionModel *m = selectionModel();
 
-    KateProjectFilterProxyModel *sortModel = new KateProjectFilterProxyModel(this);
+    auto *sortModel = new KateProjectFilterProxyModel(this);
 
     // sortModel->setFilterRole(SortFilterRole);
     // sortModel->setSortRole(SortFilterRole);
@@ -207,6 +206,10 @@ void KateProjectViewTree::addFile(const QModelIndex &idx, const QString &fileNam
 
     const QString base = idx.isValid() ? idx.data(Qt::UserRole).toString() : m_project->baseDir();
     const QString fullFileName = base + QLatin1Char('/') + fileName;
+    if (QFileInfo::exists(fullFileName)) {
+        Utils::showMessage(i18n("The file already exists"), QIcon(), i18n("Project"), MessageType::Error);
+        return;
+    }
 
     /**
      * Create an actual file on disk
@@ -219,7 +222,7 @@ void KateProjectViewTree::addFile(const QModelIndex &idx, const QString &fileNam
         return;
     }
 
-    KateProjectItem *i = new KateProjectItem(KateProjectItem::File, fileName, fullFileName);
+    auto *i = new KateProjectItem(KateProjectItem::File, fileName, fullFileName);
     item->appendRow(i);
     m_project->addFile(fullFileName, i);
     item->sortChildren(0);
@@ -241,6 +244,10 @@ void KateProjectViewTree::addDirectory(const QModelIndex &idx, const QString &na
 
     const QString base = idx.isValid() ? idx.data(Qt::UserRole).toString() : m_project->baseDir();
     const QString fullDirName = base + QLatin1Char('/') + name;
+    if (QFileInfo::exists(fullDirName)) {
+        Utils::showMessage(i18n("The directory already exists"), QIcon(), i18n("Project"), MessageType::Error);
+        return;
+    }
 
     QDir dir(base);
     if (!dir.mkdir(name)) {
@@ -249,7 +256,7 @@ void KateProjectViewTree::addDirectory(const QModelIndex &idx, const QString &na
         return;
     }
 
-    KateProjectItem *i = new KateProjectItem(KateProjectItem::Directory, name, fullDirName);
+    auto *i = new KateProjectItem(KateProjectItem::Directory, name, fullDirName);
     item->appendRow(i);
     item->sortChildren(0);
 }
