@@ -36,7 +36,7 @@ public:
     explicit KateScrollBarRestorerPrivate(KTextEditor::View *view)
     {
         // Find KateScrollBar
-        const auto scrollBars = view->findChildren<QScrollBar *>();
+        const QList<QScrollBar *> scrollBars = view->findChildren<QScrollBar *>();
         kateScrollBar = [scrollBars] {
             for (auto scrollBar : scrollBars) {
                 if (qstrcmp(scrollBar->metaObject()->className(), "KateScrollBar") == 0) {
@@ -118,7 +118,11 @@ QIcon iconForDocument(KTextEditor::Document *doc)
 
     // else mime-type icon
     else {
-        icon = QIcon::fromTheme(QMimeDatabase().mimeTypeForName(doc->mimeType()).iconName());
+        const QString mimeType = doc->mimeType();
+        // Shortcut: common case, don't initialize the mime database.
+        if (mimeType != QLatin1String("text/plain")) {
+            icon = QIcon::fromTheme(QMimeDatabase().mimeTypeForName(mimeType).iconName());
+        }
     }
 
     // ensure we always have a valid icon
@@ -132,7 +136,7 @@ QAction *toolviewShowAction(KTextEditor::MainWindow *mainWindow, const QString &
 {
     Q_ASSERT(mainWindow);
 
-    const auto clients = mainWindow->guiFactory()->clients();
+    const QList<KXMLGUIClient *> clients = mainWindow->guiFactory()->clients();
     static const QString prefix = QStringLiteral("kate_mdi_toolview_");
     auto it = std::find_if(clients.begin(), clients.end(), [](const KXMLGUIClient *c) {
         return c->componentName() == QStringLiteral("toolviewmanager");
@@ -239,8 +243,13 @@ QString niceFileNameWithPath(const QUrl &url)
     return url.toDisplayString();
 }
 
-QUrl normalizeUrl(const QUrl &url)
+QUrl normalizeUrl(QUrl url)
 {
+    // ensure proper file:// url if in doubt because no scheme set
+    if (url.isRelative()) {
+        url.setScheme(QStringLiteral("file"));
+    }
+
     // Resolve symbolic links for local files
     if (url.isLocalFile() && !KNetworkMounts::self()->isOptionEnabledForPath(url.toLocalFile(), KNetworkMounts::StrongSideEffectsOptimizations)) {
         QString normalizedUrl = QFileInfo(url.toLocalFile()).canonicalFilePath();
@@ -253,8 +262,13 @@ QUrl normalizeUrl(const QUrl &url)
     return url.adjusted(QUrl::NormalizePathSegments);
 }
 
-QUrl absoluteUrl(const QUrl &url)
+QUrl absoluteUrl(QUrl url)
 {
+    // ensure proper file:// url if in doubt because no scheme set
+    if (url.isRelative()) {
+        url.setScheme(QStringLiteral("file"));
+    }
+
     // Get absolute path if local file
     if (url.isLocalFile()) {
         return QUrl::fromLocalFile(QFileInfo(url.toLocalFile()).absoluteFilePath());
